searchData={"items":[{"type":"module","title":"Drops.Inflector","doc":"String inflection library for Elixir.\n\nThis module provides functions for transforming strings in various ways,\nincluding pluralization, singularization, camelization, and more.\n\nBased on the dry-inflector Ruby library.","ref":"Drops.Inflector.html"},{"type":"module","title":"Configuration - Drops.Inflector","doc":"You can create custom inflector modules with specific configuration using the `__using__` macro:\n\n    defmodule MyInflector do\n      use Drops.Inflector,\n        plural: [\n          {\"virus\", \"viruses\"},\n          {\"octopus\", \"octopi\"}\n        ],\n        singular: [\n          {\"thieves\", \"thief\"},\n          {\"octopi\", \"octopus\"}\n        ],\n        uncountable: [\n          \"drops-inflector\",\n          \"equipment\"\n        ],\n        acronyms: [\n          \"API\",\n          \"XML\",\n          \"HTML\"\n        ]\n    end\n\n    MyInflector.pluralize(\"virus\")     # => \"viruses\"\n    MyInflector.singularize(\"thieves\") # => \"thief\"\n    MyInflector.uncountable?(\"equipment\") # => true\n    MyInflector.camelize(\"api_access\")  # => \"APIAccess\"\n\nCustom inflectors have all the same functions as the main `Drops.Inflector` module,\nbut use your custom rules in addition to the default rules. Custom rules take\nprecedence over default rules.","ref":"Drops.Inflector.html#module-configuration"},{"type":"module","title":"Available Functions - Drops.Inflector","doc":"All inflector modules (both the main module and custom ones) provide these functions:\n\n- `camelize_lower/1` - Lower camelCase\n- `camelize_upper/1` - Upper CamelCase\n- `camelize/1` - Alias for `camelize_upper/1`\n- `modulize/1` - Convert string to module constant\n- `classify/1` - Convert to class name\n- `dasherize/1` - Convert underscores to dashes\n- `demodulize/1` - Extract last part of module name\n- `humanize/1` - Convert to human-readable form\n- `foreign_key/1` - Create foreign key name\n- `ordinalize/1` - Convert number to ordinal\n- `pluralize/1` - Convert to plural form\n- `singularize/1` - Convert to singular form\n- `tableize/1` - Convert to table name\n- `underscore/1` - Convert to snake_case\n- `uncountable?/1` - Check if word is uncountable","ref":"Drops.Inflector.html#module-available-functions"},{"type":"macro","title":"Drops.Inflector.__using__/1","doc":"Macro for creating custom inflector modules with specific configuration.","ref":"Drops.Inflector.html#__using__/1"},{"type":"macro","title":"Examples - Drops.Inflector.__using__/1","doc":"defmodule MyInflector do\n      use Drops.Inflector,\n        plural: [\n          {\"virus\", \"viruses\"}\n        ],\n        singular: [\n          {\"thieves\", \"thief\"}\n        ],\n        uncountable: [\n          \"drops-inflector\"\n        ],\n        acronyms: [\n          \"API\"\n        ]\n    end\n\n    MyInflector.pluralize(\"virus\") # => \"viruses\"\n    MyInflector.camelize(\"api_access\") # => \"APIAccess\"","ref":"Drops.Inflector.html#__using__/1-examples"},{"type":"function","title":"Drops.Inflector.camelize/2","doc":"Alias for camelize_upper/1.","ref":"Drops.Inflector.html#camelize/2"},{"type":"function","title":"Drops.Inflector.camelize_lower/2","doc":"Lower camelize a string.","ref":"Drops.Inflector.html#camelize_lower/2"},{"type":"function","title":"Examples - Drops.Inflector.camelize_lower/2","doc":"iex> Drops.Inflector.camelize_lower(\"data_mapper\")\n    \"dataMapper\"\n\n    iex> Drops.Inflector.camelize_lower(\"drops/inflector\")\n    \"drops.Inflector\"","ref":"Drops.Inflector.html#camelize_lower/2-examples"},{"type":"function","title":"Drops.Inflector.camelize_upper/2","doc":"Upper camelize a string.","ref":"Drops.Inflector.html#camelize_upper/2"},{"type":"function","title":"Examples - Drops.Inflector.camelize_upper/2","doc":"iex> Drops.Inflector.camelize_upper(\"data_mapper\")\n    \"DataMapper\"\n\n    iex> Drops.Inflector.camelize_upper(\"drops/inflector\")\n    \"Drops.Inflector\"","ref":"Drops.Inflector.html#camelize_upper/2-examples"},{"type":"function","title":"Drops.Inflector.classify/2","doc":"Classify a string.","ref":"Drops.Inflector.html#classify/2"},{"type":"function","title":"Examples - Drops.Inflector.classify/2","doc":"iex> Drops.Inflector.classify(\"books\")\n    \"Book\"\n\n    iex> Drops.Inflector.classify(\"admin.users\")\n    \"User\"","ref":"Drops.Inflector.html#classify/2-examples"},{"type":"function","title":"Drops.Inflector.dasherize/2","doc":"Dasherize a string.","ref":"Drops.Inflector.html#dasherize/2"},{"type":"function","title":"Examples - Drops.Inflector.dasherize/2","doc":"iex> Drops.Inflector.dasherize(\"drops_inflector\")\n    \"drops-inflector\"","ref":"Drops.Inflector.html#dasherize/2-examples"},{"type":"function","title":"Drops.Inflector.demodulize/2","doc":"Demodulize a string.","ref":"Drops.Inflector.html#demodulize/2"},{"type":"function","title":"Examples - Drops.Inflector.demodulize/2","doc":"iex> Drops.Inflector.demodulize(\"Drops.Inflector\")\n    \"Inflector\"\n\n    iex> Drops.Inflector.demodulize(\"String\")\n    \"String\"","ref":"Drops.Inflector.html#demodulize/2-examples"},{"type":"function","title":"Drops.Inflector.foreign_key/2","doc":"Creates a foreign key name.","ref":"Drops.Inflector.html#foreign_key/2"},{"type":"function","title":"Examples - Drops.Inflector.foreign_key/2","doc":"iex> Drops.Inflector.foreign_key(\"Message\")\n    \"message_id\"\n\n    iex> Drops.Inflector.foreign_key(\"Admin.User\")\n    \"user_id\"","ref":"Drops.Inflector.html#foreign_key/2-examples"},{"type":"function","title":"Drops.Inflector.humanize/2","doc":"Humanize a string.","ref":"Drops.Inflector.html#humanize/2"},{"type":"function","title":"Examples - Drops.Inflector.humanize/2","doc":"iex> Drops.Inflector.humanize(\"drops_inflector\")\n    \"Drops inflector\"\n\n    iex> Drops.Inflector.humanize(\"author_id\")\n    \"Author\"","ref":"Drops.Inflector.html#humanize/2-examples"},{"type":"function","title":"Drops.Inflector.modulize/2","doc":"Find a constant with the name specified in the argument string.","ref":"Drops.Inflector.html#modulize/2"},{"type":"function","title":"Examples - Drops.Inflector.modulize/2","doc":"iex> Drops.Inflector.modulize(\"String\")\n    String\n\n    iex> Drops.Inflector.modulize(\"Enum\")\n    Enum","ref":"Drops.Inflector.html#modulize/2-examples"},{"type":"function","title":"Drops.Inflector.ordinalize/2","doc":"Ordinalize a number.","ref":"Drops.Inflector.html#ordinalize/2"},{"type":"function","title":"Examples - Drops.Inflector.ordinalize/2","doc":"iex> Drops.Inflector.ordinalize(1)\n    \"1st\"\n\n    iex> Drops.Inflector.ordinalize(2)\n    \"2nd\"\n\n    iex> Drops.Inflector.ordinalize(3)\n    \"3rd\"\n\n    iex> Drops.Inflector.ordinalize(10)\n    \"10th\"\n\n    iex> Drops.Inflector.ordinalize(23)\n    \"23rd\"","ref":"Drops.Inflector.html#ordinalize/2-examples"},{"type":"function","title":"Drops.Inflector.pluralize/2","doc":"Pluralize a string.","ref":"Drops.Inflector.html#pluralize/2"},{"type":"function","title":"Examples - Drops.Inflector.pluralize/2","doc":"iex> Drops.Inflector.pluralize(\"book\")\n    \"books\"\n\n    iex> Drops.Inflector.pluralize(\"money\")\n    \"money\"","ref":"Drops.Inflector.html#pluralize/2-examples"},{"type":"function","title":"Drops.Inflector.singularize/2","doc":"Singularize a string.","ref":"Drops.Inflector.html#singularize/2"},{"type":"function","title":"Examples - Drops.Inflector.singularize/2","doc":"iex> Drops.Inflector.singularize(\"books\")\n    \"book\"\n\n    iex> Drops.Inflector.singularize(\"money\")\n    \"money\"","ref":"Drops.Inflector.html#singularize/2-examples"},{"type":"function","title":"Drops.Inflector.tableize/2","doc":"Tableize a string.","ref":"Drops.Inflector.html#tableize/2"},{"type":"function","title":"Examples - Drops.Inflector.tableize/2","doc":"iex> Drops.Inflector.tableize(\"Book\")\n    \"books\"\n\n    iex> Drops.Inflector.tableize(\"Admin.User\")\n    \"admin_users\"","ref":"Drops.Inflector.html#tableize/2-examples"},{"type":"function","title":"Drops.Inflector.uncountable?/2","doc":"Check if the input is an uncountable word.","ref":"Drops.Inflector.html#uncountable?/2"},{"type":"function","title":"Examples - Drops.Inflector.uncountable?/2","doc":"iex> Drops.Inflector.uncountable?(\"money\")\n    true\n\n    iex> Drops.Inflector.uncountable?(\"book\")\n    false","ref":"Drops.Inflector.html#uncountable?/2-examples"},{"type":"function","title":"Drops.Inflector.underscore/2","doc":"Underscore a string.","ref":"Drops.Inflector.html#underscore/2"},{"type":"function","title":"Examples - Drops.Inflector.underscore/2","doc":"iex> Drops.Inflector.underscore(\"drops-inflector\")\n    \"drops_inflector\"\n\n    iex> Drops.Inflector.underscore(\"DataMapper\")\n    \"data_mapper\"","ref":"Drops.Inflector.html#underscore/2-examples"},{"type":"module","title":"Drops.Inflector.Acronyms","doc":"A set of acronyms for proper camelization and underscoring.\n\nThis module manages acronym rules that affect how words are transformed\nduring camelization and underscoring operations.","ref":"Drops.Inflector.Acronyms.html"},{"type":"function","title":"Drops.Inflector.Acronyms.add/3","doc":"Adds a new acronym rule.","ref":"Drops.Inflector.Acronyms.html#add/3"},{"type":"function","title":"Drops.Inflector.Acronyms.apply_to/3","doc":"Applies acronym rules to a word.\n\nIf the word (lowercased) matches an acronym rule, returns the proper\nacronym form. Otherwise, capitalizes the word if capitalize is true.","ref":"Drops.Inflector.Acronyms.html#apply_to/3"},{"type":"function","title":"Drops.Inflector.Acronyms.new/0","doc":"Creates a new empty Acronyms struct.","ref":"Drops.Inflector.Acronyms.html#new/0"},{"type":"function","title":"Drops.Inflector.Acronyms.regex/1","doc":"Returns the regex pattern for matching acronyms.","ref":"Drops.Inflector.Acronyms.html#regex/1"},{"type":"type","title":"Drops.Inflector.Acronyms.t/0","doc":"","ref":"Drops.Inflector.Acronyms.html#t:t/0"},{"type":"module","title":"Drops.Inflector.Inflections","doc":"Inflection rules container.\n\nThis module manages all the inflection rules including plurals, singulars,\nuncountables, humans, and acronyms.","ref":"Drops.Inflector.Inflections.html"},{"type":"function","title":"Drops.Inflector.Inflections.acronym/2","doc":"Adds acronym rules.","ref":"Drops.Inflector.Inflections.html#acronym/2"},{"type":"function","title":"Drops.Inflector.Inflections.human/3","doc":"Adds a human rule.","ref":"Drops.Inflector.Inflections.html#human/3"},{"type":"function","title":"Drops.Inflector.Inflections.irregular/3","doc":"Adds an irregular inflection (both plural and singular).","ref":"Drops.Inflector.Inflections.html#irregular/3"},{"type":"function","title":"Drops.Inflector.Inflections.new/0","doc":"Creates a new Inflections struct with default rules.","ref":"Drops.Inflector.Inflections.html#new/0"},{"type":"function","title":"Drops.Inflector.Inflections.new/1","doc":"","ref":"Drops.Inflector.Inflections.html#new/1"},{"type":"function","title":"Drops.Inflector.Inflections.plural/3","doc":"Adds a pluralization rule.","ref":"Drops.Inflector.Inflections.html#plural/3"},{"type":"function","title":"Drops.Inflector.Inflections.singular/3","doc":"Adds a singularization rule.","ref":"Drops.Inflector.Inflections.html#singular/3"},{"type":"type","title":"Drops.Inflector.Inflections.t/0","doc":"","ref":"Drops.Inflector.Inflections.html#t:t/0"},{"type":"function","title":"Drops.Inflector.Inflections.uncountable/2","doc":"Adds uncountable words.","ref":"Drops.Inflector.Inflections.html#uncountable/2"},{"type":"module","title":"Drops.Inflector.Rules","doc":"A set of inflection rules that can be applied to words.\n\nThis module manages a list of rules (patterns and replacements) that are\napplied in order until one matches and transforms the input word.","ref":"Drops.Inflector.Rules.html"},{"type":"function","title":"Drops.Inflector.Rules.apply_to/2","doc":"Applies the rules to a word, returning the transformed word.\n\nRules are applied in order until one matches and transforms the word.\nIf no rules match, the original word is returned.","ref":"Drops.Inflector.Rules.html#apply_to/2"},{"type":"function","title":"Drops.Inflector.Rules.each/2","doc":"Iterates over all rules, calling the given function for each rule.","ref":"Drops.Inflector.Rules.html#each/2"},{"type":"function","title":"Drops.Inflector.Rules.insert/3","doc":"Inserts a rule at the specified index.","ref":"Drops.Inflector.Rules.html#insert/3"},{"type":"function","title":"Drops.Inflector.Rules.new/0","doc":"Creates a new empty Rules struct.","ref":"Drops.Inflector.Rules.html#new/0"},{"type":"type","title":"Drops.Inflector.Rules.rule/0","doc":"","ref":"Drops.Inflector.Rules.html#t:rule/0"},{"type":"type","title":"Drops.Inflector.Rules.t/0","doc":"","ref":"Drops.Inflector.Rules.html#t:t/0"},{"type":"extras","title":"Elixir Drops 💦","doc":"# Elixir Drops 💦","ref":"readme.html"},{"type":"extras","title":"Inflector - Elixir Drops 💦","doc":"[![CI](https://github.com/solnic/drops/actions/workflows/ci.yml/badge.svg)](https://github.com/solnic/drops_inflector/actions/workflows/ci.yml) [![Hex pm](https://img.shields.io/hexpm/v/drops_inflector.svg?style=flat)](https://hex.pm/packages/drops_inflector) [![hex.pm downloads](https://img.shields.io/hexpm/dt/drops_inflector.svg?style=flat)](https://hex.pm/packages/drops_inflector)\n\n\nInflection utils for Elixir.","ref":"readme.html#inflector"},{"type":"extras","title":"Installation - Elixir Drops 💦","doc":"```elixir\ndef deps do\n  [\n    {:drops_inflector, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Links - Elixir Drops 💦","doc":"- [Documentation](https://hexdocs.pm/drops_inflector)","ref":"readme.html#links"},{"type":"extras","title":"Basic Usage - Elixir Drops 💦","doc":"The `Drops.Inflector` module provides a comprehensive set of string inflection functions:\n\n```elixir\n# Pluralization and singularization\nDrops.Inflector.pluralize(\"book\")        # => \"books\"\nDrops.Inflector.pluralize(\"person\")      # => \"people\"\nDrops.Inflector.singularize(\"books\")     # => \"book\"\nDrops.Inflector.singularize(\"children\")  # => \"child\"\n\n# Case transformations\nDrops.Inflector.camelize(\"data_mapper\")        # => \"DataMapper\"\nDrops.Inflector.camelize_lower(\"data_mapper\")  # => \"dataMapper\"\nDrops.Inflector.underscore(\"DataMapper\")       # => \"data_mapper\"\nDrops.Inflector.dasherize(\"drops_inflector\")   # => \"drops-inflector\"\n\n# Human-friendly transformations\nDrops.Inflector.humanize(\"drops_inflector\")  # => \"Drops inflector\"\nDrops.Inflector.humanize(\"author_id\")        # => \"Author\"\n\n# Database and class name transformations\nDrops.Inflector.tableize(\"User\")           # => \"users\"\nDrops.Inflector.classify(\"admin_users\")    # => \"AdminUser\"\nDrops.Inflector.foreign_key(\"Message\")     # => \"message_id\"\n\n# Module operations\nDrops.Inflector.demodulize(\"Drops.Inflector\")  # => \"Inflector\"\nDrops.Inflector.modulize(\"String\")             # => String\n\n# Number ordinalization\nDrops.Inflector.ordinalize(1)   # => \"1st\"\nDrops.Inflector.ordinalize(22)  # => \"22nd\"\nDrops.Inflector.ordinalize(103) # => \"103rd\"\n\n# Check if a word is uncountable\nDrops.Inflector.uncountable?(\"money\")       # => true\nDrops.Inflector.uncountable?(\"information\") # => true\nDrops.Inflector.uncountable?(\"book\")        # => false\n```","ref":"readme.html#basic-usage"},{"type":"extras","title":"Custom Inflectors - Elixir Drops 💦","doc":"You can create custom inflector modules with specific rules using the `use` macro. Custom rules take precedence over default rules:\n\n```elixir\ndefmodule MyInflector do\n  use Drops.Inflector,\n    plural: [\n      {\"virus\", \"viruses\"},\n      {\"octopus\", \"octopi\"}\n    ],\n    singular: [\n      {\"thieves\", \"thief\"},\n      {\"octopi\", \"octopus\"}\n    ],\n    uncountable: [\n      \"equipment\",\n      \"software\"\n    ],\n    acronyms: [\n      \"API\",\n      \"XML\",\n      \"HTML\"\n    ]\nend\n\n# Use your custom inflector\nMyInflector.pluralize(\"virus\")     # => \"viruses\"\nMyInflector.singularize(\"thieves\") # => \"thief\"\nMyInflector.uncountable?(\"equipment\") # => true\n\n# Acronyms are properly handled in camelization\nMyInflector.camelize(\"api_access\")     # => \"APIAccess\"\nMyInflector.camelize_lower(\"xml_data\") # => \"xmlData\"\n\n# All other functions work the same way\nMyInflector.camelize(\"data_mapper\")    # => \"DataMapper\"\nMyInflector.tableize(\"User\")           # => \"users\"\n```","ref":"readme.html#custom-inflectors"},{"type":"extras","title":"Acronym Support - Elixir Drops 💦","doc":"Drops.Inflector includes built-in support for common acronyms like API, JSON, HTTP, etc. You can also define custom acronyms that will be properly handled during camelization:\n\n```elixir\ndefmodule APIInflector do\n  use Drops.Inflector,\n    acronyms: [\"API\", \"XML\", \"HTML\", \"CSS\"]\nend\n\nAPIInflector.camelize(\"api_access\")        # => \"APIAccess\"\nAPIInflector.camelize(\"xml_http_request\")  # => \"XMLHTTPRequest\"\nAPIInflector.camelize_lower(\"html_css\")    # => \"htmlCSS\"\n```\n\nThe default inflector already includes these acronyms: API, CSRF, CSV, DB, HMAC, HTTP, JSON, OpenSSL.","ref":"readme.html#acronym-support"},{"type":"extras","title":"Multiple Custom Inflectors - Elixir Drops 💦","doc":"You can create multiple inflectors with different rules:\n\n```elixir\ndefmodule MedicalInflector do\n  use Drops.Inflector,\n    plural: [\n      {\"virus\", \"viruses\"},\n      {\"bacterium\", \"bacteria\"}\n    ]\nend\n\ndefmodule TechInflector do\n  use Drops.Inflector,\n    plural: [\n      {\"server\", \"servers\"},\n      {\"database\", \"databases\"}\n    ],\n    uncountable: [\n      \"software\",\n      \"hardware\"\n    ]\nend\n\nMedicalInflector.pluralize(\"virus\")    # => \"viruses\"\nTechInflector.pluralize(\"server\")      # => \"servers\"\nTechInflector.uncountable?(\"software\") # => true\n```","ref":"readme.html#multiple-custom-inflectors"},{"type":"extras","title":"0.1.0 2025-07-18","doc":"# 0.1.0 2025-07-18\n\nInitial public release.","ref":"changelog.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}